@@ -17,8 +17,6 @@ from ocrd_utils import (
 )
 from ocrd_modelfactory import page_from_file
 from ocrd_models.ocrd_page import (
-    LabelType, LabelsType,
-    MetadataItemType,
     AlternativeImageType,
     to_xml
 )
@@ -65,18 +63,8 @@ class SkimageDenoise(Processor):
             LOG.info("INPUT FILE %i / %s", n, page_id)
             
             pcgts = page_from_file(self.workspace.download_file(input_file))
+            self.add_metadata(pcgts)
             page = pcgts.get_Page()
-            metadata = pcgts.get_Metadata() # ensured by from_file()
-            metadata.add_MetadataItem(
-                MetadataItemType(type_="processingStep",
-                                 name=self.ocrd_tool['steps'][0],
-                                 value=TOOL,
-                                 Labels=[LabelsType(
-                                     externalModel="ocrd-tool",
-                                     externalId="parameters",
-                                     Label=[LabelType(type_=name,
-                                                      value=self.parameter[name])
-                                            for name in self.parameter.keys()])]))
             
             for page in [page]:
                 page_image, page_coords, page_image_info = self.workspace.image_from_page(
@@ -109,7 +97,7 @@ class SkimageDenoise(Processor):
                         region, page_image, page_coords, feature_selector='binarized')
                     if oplevel == 'region':
                         self._process_segment(region, region_image, region_coords, maxsize,
-                                              "region '%s'" % region.id, None,
+                                              "region '%s'" % region.id, input_file.pageId,
                                               file_id + '.IMG-DEN_' + region.id)
                         continue
                     lines = region.get_TextLine()
@@ -120,7 +108,7 @@ class SkimageDenoise(Processor):
                             line, region_image, region_coords, feature_selector='binarized')
                         if oplevel == 'line':
                             self._process_segment(line, line_image, line_coords, maxsize,
-                                                  "line '%s'" % line.id, None,
+                                                  "line '%s'" % line.id, input_file.pageId,
                                                   file_id + '.IMG-DEN_' + line.id)
                             continue
                         words = line.get_Word()
@@ -131,7 +119,7 @@ class SkimageDenoise(Processor):
                                 word, line_image, line_coords, feature_selector='binarized')
                             if oplevel == 'word':
                                 self._process_segment(word, word_image, word_coords, maxsize,
-                                                      "word '%s'" % word.id, None,
+                                                      "word '%s'" % word.id, input_file.pageId,
                                                       file_id + '.IMG-DEN_' + word.id)
                                 continue
                             glyphs = word.get_Glyph()
@@ -141,7 +129,7 @@ class SkimageDenoise(Processor):
                                 glyph_image, glyph_coords = self.workspace.image_from_segment(
                                     glyph, word_image, word_coords, feature_selector='binarized')
                                 self._process_segment(glyph, glyph_image, glyph_coords, maxsize,
-                                                      "glyph '%s'" % glyph.id, None,
+                                                      "glyph '%s'" % glyph.id, input_file.pageId,
                                                       file_id + '.IMG-DEN_' + glyph.id)
             
             pcgts.set_pcGtsId(file_id)
@@ -158,7 +146,7 @@ class SkimageDenoise(Processor):
         LOG = getLogger('processor.SkimageDenoise')
         features = coords['features'] # features already applied to image
         features += ',despeckled'
-        array = np.array(image)
+        array = np.array(image).astype('bool')
         # suppress bg specks in fg (holes in binary-inverted)
         remove_small_objects(array, min_size=maxsize, in_place=True)
         # suppress fg specks in bg (blobs in binary-inverted)
